# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/network.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/network.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\013network_pb2'),
  serialized_pb=_b('\n\x1e\x64gt_sdk/protobuf/network.proto\"\x13\n\x11\x44isconnectMessage\"\xd9\x01\n\x13PeerRegisterRequest\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x18\n\x10protocol_version\x18\x02 \x01(\r\x12/\n\x04mode\x18\x03 \x01(\x0e\x32!.PeerRegisterRequest.RegisterMode\x12\x0b\n\x03pid\x18\x04 \x01(\r\x12\x11\n\tcomponent\x18\x05 \x01(\t\x12\x10\n\x08\x65xtpoint\x18\x06 \x01(\t\x12\x0b\n\x03hid\x18\x07 \x01(\t\"&\n\x0cRegisterMode\x12\x0c\n\x08REGISTER\x10\x00\x12\x08\n\x04SYNC\x10\x01\"\x17\n\x15PeerUnregisterRequest\"r\n\x0fGetPeersRequest\x12\x0f\n\x07peer_id\x18\x01 \x01(\x0c\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\x12\x0f\n\x07\x63luster\x18\x03 \x01(\t\x12\x0b\n\x03KYC\x18\x04 \x01(\t\x12\x0f\n\x07network\x18\x05 \x01(\t\x12\r\n\x05\x62\x61tch\x18\x06 \x01(\t\"\x85\x02\n\x10GetPeersResponse\x12\x30\n\x06status\x18\x01 \x01(\x0e\x32 .GetPeersResponse.GetPeersStatus\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12\x16\n\x0epeer_endpoints\x18\x03 \x03(\t\"\x95\x01\n\x0eGetPeersStatus\x12\x06\n\x02OK\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0c\n\x08REDIRECT\x10\x02\x12\n\n\x06\x44\x45NIED\x10\x03\x12\n\n\x06JOINED\x10\x04\x12\x0c\n\x08\x44YNPEERS\x10\x05\x12\x0b\n\x07NOSPACE\x10\x06\x12\x0b\n\x07WAITING\x10\x07\x12\x0c\n\x08PEERSTAT\x10\x08\x12\x12\n\x0eNOT_VALID_CERT\x10\t\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\xc1\x01\n\rGossipMessage\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x30\n\x0c\x63ontent_type\x18\x02 \x01(\x0e\x32\x1a.GossipMessage.ContentType\x12\x14\n\x0ctime_to_live\x18\x03 \x01(\r\"W\n\x0b\x43ontentType\x12\x16\n\x12\x43ONTENT_TYPE_UNSET\x10\x00\x12\t\n\x05\x42LOCK\x10\x01\x12\t\n\x05\x42\x41TCH\x10\x02\x12\x0b\n\x07\x42\x41TCHES\x10\x03\x12\r\n\tENDPOINTS\x10\x04\"\x92\x01\n\x16NetworkAcknowledgement\x12.\n\x06status\x18\x01 \x01(\x0e\x32\x1e.NetworkAcknowledgement.Status\x12\x0b\n\x03pid\x18\x02 \x01(\r\x12\x0c\n\x04sync\x18\x03 \x01(\x08\"-\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"K\n\x12GossipBlockRequest\x12\x10\n\x08\x62lock_id\x18\x01 \x01(\t\x12\r\n\x05nonce\x18\x02 \x01(\t\x12\x14\n\x0ctime_to_live\x18\x03 \x01(\r\"4\n\x13GossipBlockResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x0c\n\x04nest\x18\x02 \x01(\x08\"&\n\x13GossipBatchResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"N\n\x1bGossipBatchByBatchIdRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05nonce\x18\x02 \x01(\t\x12\x14\n\x0ctime_to_live\x18\x03 \x01(\r\"U\n!GossipBatchByTransactionIdRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\r\n\x05nonce\x18\x02 \x01(\t\x12\x14\n\x0ctime_to_live\x18\x03 \x01(\r\"R\n\x16GossipConsensusMessage\x12\x0f\n\x07message\x18\x01 \x01(\x0c\x12\x11\n\tsender_id\x18\x02 \x01(\x0c\x12\x14\n\x0ctime_to_live\x18\x03 \x01(\r\"1\n\x0c\x45ndpointItem\x12\x0f\n\x07peer_id\x18\x01 \x01(\x0c\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\"0\n\x0c\x45ndpointList\x12 \n\tendpoints\x18\x01 \x03(\x0b\x32\r.EndpointItemB&\n\x15sawtooth.sdk.protobufP\x01Z\x0bnetwork_pb2b\x06proto3')
)



_PEERREGISTERREQUEST_REGISTERMODE = _descriptor.EnumDescriptor(
  name='RegisterMode',
  full_name='PeerRegisterRequest.RegisterMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REGISTER', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYNC', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=235,
  serialized_end=273,
)
_sym_db.RegisterEnumDescriptor(_PEERREGISTERREQUEST_REGISTERMODE)

_GETPEERSRESPONSE_GETPEERSSTATUS = _descriptor.EnumDescriptor(
  name='GetPeersStatus',
  full_name='GetPeersResponse.GetPeersStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REDIRECT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DENIED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JOINED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DYNPEERS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOSPACE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAITING', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PEERSTAT', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_VALID_CERT', index=9, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=529,
  serialized_end=678,
)
_sym_db.RegisterEnumDescriptor(_GETPEERSRESPONSE_GETPEERSSTATUS)

_GOSSIPMESSAGE_CONTENTTYPE = _descriptor.EnumDescriptor(
  name='ContentType',
  full_name='GossipMessage.ContentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTENT_TYPE_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLOCK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BATCH', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BATCHES', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENDPOINTS', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=818,
  serialized_end=905,
)
_sym_db.RegisterEnumDescriptor(_GOSSIPMESSAGE_CONTENTTYPE)

_NETWORKACKNOWLEDGEMENT_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='NetworkAcknowledgement.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1009,
  serialized_end=1054,
)
_sym_db.RegisterEnumDescriptor(_NETWORKACKNOWLEDGEMENT_STATUS)


_DISCONNECTMESSAGE = _descriptor.Descriptor(
  name='DisconnectMessage',
  full_name='DisconnectMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=53,
)


_PEERREGISTERREQUEST = _descriptor.Descriptor(
  name='PeerRegisterRequest',
  full_name='PeerRegisterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='PeerRegisterRequest.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='PeerRegisterRequest.protocol_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='PeerRegisterRequest.mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid', full_name='PeerRegisterRequest.pid', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='component', full_name='PeerRegisterRequest.component', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extpoint', full_name='PeerRegisterRequest.extpoint', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hid', full_name='PeerRegisterRequest.hid', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PEERREGISTERREQUEST_REGISTERMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=273,
)


_PEERUNREGISTERREQUEST = _descriptor.Descriptor(
  name='PeerUnregisterRequest',
  full_name='PeerUnregisterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=298,
)


_GETPEERSREQUEST = _descriptor.Descriptor(
  name='GetPeersRequest',
  full_name='GetPeersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_id', full_name='GetPeersRequest.peer_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='GetPeersRequest.endpoint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='GetPeersRequest.cluster', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='KYC', full_name='GetPeersRequest.KYC', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='network', full_name='GetPeersRequest.network', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch', full_name='GetPeersRequest.batch', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=414,
)


_GETPEERSRESPONSE = _descriptor.Descriptor(
  name='GetPeersResponse',
  full_name='GetPeersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='GetPeersResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='GetPeersResponse.cluster', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer_endpoints', full_name='GetPeersResponse.peer_endpoints', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETPEERSRESPONSE_GETPEERSSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=678,
)


_PINGREQUEST = _descriptor.Descriptor(
  name='PingRequest',
  full_name='PingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=680,
  serialized_end=693,
)


_PINGRESPONSE = _descriptor.Descriptor(
  name='PingResponse',
  full_name='PingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=695,
  serialized_end=709,
)


_GOSSIPMESSAGE = _descriptor.Descriptor(
  name='GossipMessage',
  full_name='GossipMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='GossipMessage.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='GossipMessage.content_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='GossipMessage.time_to_live', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GOSSIPMESSAGE_CONTENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=712,
  serialized_end=905,
)


_NETWORKACKNOWLEDGEMENT = _descriptor.Descriptor(
  name='NetworkAcknowledgement',
  full_name='NetworkAcknowledgement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='NetworkAcknowledgement.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid', full_name='NetworkAcknowledgement.pid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sync', full_name='NetworkAcknowledgement.sync', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NETWORKACKNOWLEDGEMENT_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=908,
  serialized_end=1054,
)


_GOSSIPBLOCKREQUEST = _descriptor.Descriptor(
  name='GossipBlockRequest',
  full_name='GossipBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_id', full_name='GossipBlockRequest.block_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='GossipBlockRequest.nonce', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='GossipBlockRequest.time_to_live', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1056,
  serialized_end=1131,
)


_GOSSIPBLOCKRESPONSE = _descriptor.Descriptor(
  name='GossipBlockResponse',
  full_name='GossipBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='GossipBlockResponse.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nest', full_name='GossipBlockResponse.nest', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1133,
  serialized_end=1185,
)


_GOSSIPBATCHRESPONSE = _descriptor.Descriptor(
  name='GossipBatchResponse',
  full_name='GossipBatchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='GossipBatchResponse.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1187,
  serialized_end=1225,
)


_GOSSIPBATCHBYBATCHIDREQUEST = _descriptor.Descriptor(
  name='GossipBatchByBatchIdRequest',
  full_name='GossipBatchByBatchIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='GossipBatchByBatchIdRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='GossipBatchByBatchIdRequest.nonce', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='GossipBatchByBatchIdRequest.time_to_live', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1227,
  serialized_end=1305,
)


_GOSSIPBATCHBYTRANSACTIONIDREQUEST = _descriptor.Descriptor(
  name='GossipBatchByTransactionIdRequest',
  full_name='GossipBatchByTransactionIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='GossipBatchByTransactionIdRequest.ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='GossipBatchByTransactionIdRequest.nonce', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='GossipBatchByTransactionIdRequest.time_to_live', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1307,
  serialized_end=1392,
)


_GOSSIPCONSENSUSMESSAGE = _descriptor.Descriptor(
  name='GossipConsensusMessage',
  full_name='GossipConsensusMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='GossipConsensusMessage.message', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_id', full_name='GossipConsensusMessage.sender_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='GossipConsensusMessage.time_to_live', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1394,
  serialized_end=1476,
)


_ENDPOINTITEM = _descriptor.Descriptor(
  name='EndpointItem',
  full_name='EndpointItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_id', full_name='EndpointItem.peer_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='EndpointItem.endpoint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1478,
  serialized_end=1527,
)


_ENDPOINTLIST = _descriptor.Descriptor(
  name='EndpointList',
  full_name='EndpointList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoints', full_name='EndpointList.endpoints', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1529,
  serialized_end=1577,
)

_PEERREGISTERREQUEST.fields_by_name['mode'].enum_type = _PEERREGISTERREQUEST_REGISTERMODE
_PEERREGISTERREQUEST_REGISTERMODE.containing_type = _PEERREGISTERREQUEST
_GETPEERSRESPONSE.fields_by_name['status'].enum_type = _GETPEERSRESPONSE_GETPEERSSTATUS
_GETPEERSRESPONSE_GETPEERSSTATUS.containing_type = _GETPEERSRESPONSE
_GOSSIPMESSAGE.fields_by_name['content_type'].enum_type = _GOSSIPMESSAGE_CONTENTTYPE
_GOSSIPMESSAGE_CONTENTTYPE.containing_type = _GOSSIPMESSAGE
_NETWORKACKNOWLEDGEMENT.fields_by_name['status'].enum_type = _NETWORKACKNOWLEDGEMENT_STATUS
_NETWORKACKNOWLEDGEMENT_STATUS.containing_type = _NETWORKACKNOWLEDGEMENT
_ENDPOINTLIST.fields_by_name['endpoints'].message_type = _ENDPOINTITEM
DESCRIPTOR.message_types_by_name['DisconnectMessage'] = _DISCONNECTMESSAGE
DESCRIPTOR.message_types_by_name['PeerRegisterRequest'] = _PEERREGISTERREQUEST
DESCRIPTOR.message_types_by_name['PeerUnregisterRequest'] = _PEERUNREGISTERREQUEST
DESCRIPTOR.message_types_by_name['GetPeersRequest'] = _GETPEERSREQUEST
DESCRIPTOR.message_types_by_name['GetPeersResponse'] = _GETPEERSRESPONSE
DESCRIPTOR.message_types_by_name['PingRequest'] = _PINGREQUEST
DESCRIPTOR.message_types_by_name['PingResponse'] = _PINGRESPONSE
DESCRIPTOR.message_types_by_name['GossipMessage'] = _GOSSIPMESSAGE
DESCRIPTOR.message_types_by_name['NetworkAcknowledgement'] = _NETWORKACKNOWLEDGEMENT
DESCRIPTOR.message_types_by_name['GossipBlockRequest'] = _GOSSIPBLOCKREQUEST
DESCRIPTOR.message_types_by_name['GossipBlockResponse'] = _GOSSIPBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['GossipBatchResponse'] = _GOSSIPBATCHRESPONSE
DESCRIPTOR.message_types_by_name['GossipBatchByBatchIdRequest'] = _GOSSIPBATCHBYBATCHIDREQUEST
DESCRIPTOR.message_types_by_name['GossipBatchByTransactionIdRequest'] = _GOSSIPBATCHBYTRANSACTIONIDREQUEST
DESCRIPTOR.message_types_by_name['GossipConsensusMessage'] = _GOSSIPCONSENSUSMESSAGE
DESCRIPTOR.message_types_by_name['EndpointItem'] = _ENDPOINTITEM
DESCRIPTOR.message_types_by_name['EndpointList'] = _ENDPOINTLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DisconnectMessage = _reflection.GeneratedProtocolMessageType('DisconnectMessage', (_message.Message,), dict(
  DESCRIPTOR = _DISCONNECTMESSAGE,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:DisconnectMessage)
  ))
_sym_db.RegisterMessage(DisconnectMessage)

PeerRegisterRequest = _reflection.GeneratedProtocolMessageType('PeerRegisterRequest', (_message.Message,), dict(
  DESCRIPTOR = _PEERREGISTERREQUEST,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:PeerRegisterRequest)
  ))
_sym_db.RegisterMessage(PeerRegisterRequest)

PeerUnregisterRequest = _reflection.GeneratedProtocolMessageType('PeerUnregisterRequest', (_message.Message,), dict(
  DESCRIPTOR = _PEERUNREGISTERREQUEST,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:PeerUnregisterRequest)
  ))
_sym_db.RegisterMessage(PeerUnregisterRequest)

GetPeersRequest = _reflection.GeneratedProtocolMessageType('GetPeersRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETPEERSREQUEST,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GetPeersRequest)
  ))
_sym_db.RegisterMessage(GetPeersRequest)

GetPeersResponse = _reflection.GeneratedProtocolMessageType('GetPeersResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETPEERSRESPONSE,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GetPeersResponse)
  ))
_sym_db.RegisterMessage(GetPeersResponse)

PingRequest = _reflection.GeneratedProtocolMessageType('PingRequest', (_message.Message,), dict(
  DESCRIPTOR = _PINGREQUEST,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:PingRequest)
  ))
_sym_db.RegisterMessage(PingRequest)

PingResponse = _reflection.GeneratedProtocolMessageType('PingResponse', (_message.Message,), dict(
  DESCRIPTOR = _PINGRESPONSE,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:PingResponse)
  ))
_sym_db.RegisterMessage(PingResponse)

GossipMessage = _reflection.GeneratedProtocolMessageType('GossipMessage', (_message.Message,), dict(
  DESCRIPTOR = _GOSSIPMESSAGE,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GossipMessage)
  ))
_sym_db.RegisterMessage(GossipMessage)

NetworkAcknowledgement = _reflection.GeneratedProtocolMessageType('NetworkAcknowledgement', (_message.Message,), dict(
  DESCRIPTOR = _NETWORKACKNOWLEDGEMENT,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:NetworkAcknowledgement)
  ))
_sym_db.RegisterMessage(NetworkAcknowledgement)

GossipBlockRequest = _reflection.GeneratedProtocolMessageType('GossipBlockRequest', (_message.Message,), dict(
  DESCRIPTOR = _GOSSIPBLOCKREQUEST,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GossipBlockRequest)
  ))
_sym_db.RegisterMessage(GossipBlockRequest)

GossipBlockResponse = _reflection.GeneratedProtocolMessageType('GossipBlockResponse', (_message.Message,), dict(
  DESCRIPTOR = _GOSSIPBLOCKRESPONSE,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GossipBlockResponse)
  ))
_sym_db.RegisterMessage(GossipBlockResponse)

GossipBatchResponse = _reflection.GeneratedProtocolMessageType('GossipBatchResponse', (_message.Message,), dict(
  DESCRIPTOR = _GOSSIPBATCHRESPONSE,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GossipBatchResponse)
  ))
_sym_db.RegisterMessage(GossipBatchResponse)

GossipBatchByBatchIdRequest = _reflection.GeneratedProtocolMessageType('GossipBatchByBatchIdRequest', (_message.Message,), dict(
  DESCRIPTOR = _GOSSIPBATCHBYBATCHIDREQUEST,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GossipBatchByBatchIdRequest)
  ))
_sym_db.RegisterMessage(GossipBatchByBatchIdRequest)

GossipBatchByTransactionIdRequest = _reflection.GeneratedProtocolMessageType('GossipBatchByTransactionIdRequest', (_message.Message,), dict(
  DESCRIPTOR = _GOSSIPBATCHBYTRANSACTIONIDREQUEST,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GossipBatchByTransactionIdRequest)
  ))
_sym_db.RegisterMessage(GossipBatchByTransactionIdRequest)

GossipConsensusMessage = _reflection.GeneratedProtocolMessageType('GossipConsensusMessage', (_message.Message,), dict(
  DESCRIPTOR = _GOSSIPCONSENSUSMESSAGE,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:GossipConsensusMessage)
  ))
_sym_db.RegisterMessage(GossipConsensusMessage)

EndpointItem = _reflection.GeneratedProtocolMessageType('EndpointItem', (_message.Message,), dict(
  DESCRIPTOR = _ENDPOINTITEM,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:EndpointItem)
  ))
_sym_db.RegisterMessage(EndpointItem)

EndpointList = _reflection.GeneratedProtocolMessageType('EndpointList', (_message.Message,), dict(
  DESCRIPTOR = _ENDPOINTLIST,
  __module__ = 'dgt_sdk.protobuf.network_pb2'
  # @@protoc_insertion_point(class_scope:EndpointList)
  ))
_sym_db.RegisterMessage(EndpointList)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/state_context.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dgt_sdk.protobuf import events_pb2 as dgt__sdk_dot_protobuf_dot_events__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/state_context.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\021state_context_pb2'),
  serialized_pb=_b('\n$dgt_sdk/protobuf/state_context.proto\x1a\x1d\x64gt_sdk/protobuf/events.proto\"-\n\x0cTpStateEntry\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\":\n\x11TpStateGetRequest\x12\x12\n\ncontext_id\x18\x01 \x01(\t\x12\x11\n\taddresses\x18\x02 \x03(\t\"\x9d\x01\n\x12TpStateGetResponse\x12\x1e\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\r.TpStateEntry\x12*\n\x06status\x18\x02 \x01(\x0e\x32\x1a.TpStateGetResponse.Status\";\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x17\n\x13\x41UTHORIZATION_ERROR\x10\x02\"G\n\x11TpStateSetRequest\x12\x12\n\ncontext_id\x18\x01 \x01(\t\x12\x1e\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\r.TpStateEntry\"\x90\x01\n\x12TpStateSetResponse\x12\x11\n\taddresses\x18\x01 \x03(\t\x12*\n\x06status\x18\x02 \x01(\x0e\x32\x1a.TpStateSetResponse.Status\";\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x17\n\x13\x41UTHORIZATION_ERROR\x10\x02\"=\n\x14TpStateDeleteRequest\x12\x12\n\ncontext_id\x18\x01 \x01(\t\x12\x11\n\taddresses\x18\x02 \x03(\t\"\x96\x01\n\x15TpStateDeleteResponse\x12\x11\n\taddresses\x18\x01 \x03(\t\x12-\n\x06status\x18\x02 \x01(\x0e\x32\x1d.TpStateDeleteResponse.Status\";\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x17\n\x13\x41UTHORIZATION_ERROR\x10\x02\";\n\x17TpReceiptAddDataRequest\x12\x12\n\ncontext_id\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"{\n\x18TpReceiptAddDataResponse\x12\x30\n\x06status\x18\x02 \x01(\x0e\x32 .TpReceiptAddDataResponse.Status\"-\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\">\n\x11TpEventAddRequest\x12\x12\n\ncontext_id\x18\x01 \x01(\t\x12\x15\n\x05\x65vent\x18\x02 \x01(\x0b\x32\x06.Event\"o\n\x12TpEventAddResponse\x12*\n\x06status\x18\x02 \x01(\x0e\x32\x1a.TpEventAddResponse.Status\"-\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x42,\n\x15sawtooth.sdk.protobufP\x01Z\x11state_context_pb2b\x06proto3')
  ,
  dependencies=[dgt__sdk_dot_protobuf_dot_events__pb2.DESCRIPTOR,])



_TPSTATEGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='TpStateGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=277,
  serialized_end=336,
)
_sym_db.RegisterEnumDescriptor(_TPSTATEGETRESPONSE_STATUS)

_TPSTATESETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='TpStateSetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=277,
  serialized_end=336,
)
_sym_db.RegisterEnumDescriptor(_TPSTATESETRESPONSE_STATUS)

_TPSTATEDELETERESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='TpStateDeleteResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=277,
  serialized_end=336,
)
_sym_db.RegisterEnumDescriptor(_TPSTATEDELETERESPONSE_STATUS)

_TPRECEIPTADDDATARESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='TpReceiptAddDataResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=913,
  serialized_end=958,
)
_sym_db.RegisterEnumDescriptor(_TPRECEIPTADDDATARESPONSE_STATUS)

_TPEVENTADDRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='TpEventAddResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=913,
  serialized_end=958,
)
_sym_db.RegisterEnumDescriptor(_TPEVENTADDRESPONSE_STATUS)


_TPSTATEENTRY = _descriptor.Descriptor(
  name='TpStateEntry',
  full_name='TpStateEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='TpStateEntry.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='TpStateEntry.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=116,
)


_TPSTATEGETREQUEST = _descriptor.Descriptor(
  name='TpStateGetRequest',
  full_name='TpStateGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='context_id', full_name='TpStateGetRequest.context_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='addresses', full_name='TpStateGetRequest.addresses', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=118,
  serialized_end=176,
)


_TPSTATEGETRESPONSE = _descriptor.Descriptor(
  name='TpStateGetResponse',
  full_name='TpStateGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='TpStateGetResponse.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='TpStateGetResponse.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TPSTATEGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=336,
)


_TPSTATESETREQUEST = _descriptor.Descriptor(
  name='TpStateSetRequest',
  full_name='TpStateSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='context_id', full_name='TpStateSetRequest.context_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='TpStateSetRequest.entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=409,
)


_TPSTATESETRESPONSE = _descriptor.Descriptor(
  name='TpStateSetResponse',
  full_name='TpStateSetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='TpStateSetResponse.addresses', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='TpStateSetResponse.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TPSTATESETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=412,
  serialized_end=556,
)


_TPSTATEDELETEREQUEST = _descriptor.Descriptor(
  name='TpStateDeleteRequest',
  full_name='TpStateDeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='context_id', full_name='TpStateDeleteRequest.context_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='addresses', full_name='TpStateDeleteRequest.addresses', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=558,
  serialized_end=619,
)


_TPSTATEDELETERESPONSE = _descriptor.Descriptor(
  name='TpStateDeleteResponse',
  full_name='TpStateDeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='TpStateDeleteResponse.addresses', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='TpStateDeleteResponse.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TPSTATEDELETERESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=622,
  serialized_end=772,
)


_TPRECEIPTADDDATAREQUEST = _descriptor.Descriptor(
  name='TpReceiptAddDataRequest',
  full_name='TpReceiptAddDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='context_id', full_name='TpReceiptAddDataRequest.context_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='TpReceiptAddDataRequest.data', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=833,
)


_TPRECEIPTADDDATARESPONSE = _descriptor.Descriptor(
  name='TpReceiptAddDataResponse',
  full_name='TpReceiptAddDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='TpReceiptAddDataResponse.status', index=0,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TPRECEIPTADDDATARESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=835,
  serialized_end=958,
)


_TPEVENTADDREQUEST = _descriptor.Descriptor(
  name='TpEventAddRequest',
  full_name='TpEventAddRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='context_id', full_name='TpEventAddRequest.context_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event', full_name='TpEventAddRequest.event', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=960,
  serialized_end=1022,
)


_TPEVENTADDRESPONSE = _descriptor.Descriptor(
  name='TpEventAddResponse',
  full_name='TpEventAddResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='TpEventAddResponse.status', index=0,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TPEVENTADDRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1024,
  serialized_end=1135,
)

_TPSTATEGETRESPONSE.fields_by_name['entries'].message_type = _TPSTATEENTRY
_TPSTATEGETRESPONSE.fields_by_name['status'].enum_type = _TPSTATEGETRESPONSE_STATUS
_TPSTATEGETRESPONSE_STATUS.containing_type = _TPSTATEGETRESPONSE
_TPSTATESETREQUEST.fields_by_name['entries'].message_type = _TPSTATEENTRY
_TPSTATESETRESPONSE.fields_by_name['status'].enum_type = _TPSTATESETRESPONSE_STATUS
_TPSTATESETRESPONSE_STATUS.containing_type = _TPSTATESETRESPONSE
_TPSTATEDELETERESPONSE.fields_by_name['status'].enum_type = _TPSTATEDELETERESPONSE_STATUS
_TPSTATEDELETERESPONSE_STATUS.containing_type = _TPSTATEDELETERESPONSE
_TPRECEIPTADDDATARESPONSE.fields_by_name['status'].enum_type = _TPRECEIPTADDDATARESPONSE_STATUS
_TPRECEIPTADDDATARESPONSE_STATUS.containing_type = _TPRECEIPTADDDATARESPONSE
_TPEVENTADDREQUEST.fields_by_name['event'].message_type = dgt__sdk_dot_protobuf_dot_events__pb2._EVENT
_TPEVENTADDRESPONSE.fields_by_name['status'].enum_type = _TPEVENTADDRESPONSE_STATUS
_TPEVENTADDRESPONSE_STATUS.containing_type = _TPEVENTADDRESPONSE
DESCRIPTOR.message_types_by_name['TpStateEntry'] = _TPSTATEENTRY
DESCRIPTOR.message_types_by_name['TpStateGetRequest'] = _TPSTATEGETREQUEST
DESCRIPTOR.message_types_by_name['TpStateGetResponse'] = _TPSTATEGETRESPONSE
DESCRIPTOR.message_types_by_name['TpStateSetRequest'] = _TPSTATESETREQUEST
DESCRIPTOR.message_types_by_name['TpStateSetResponse'] = _TPSTATESETRESPONSE
DESCRIPTOR.message_types_by_name['TpStateDeleteRequest'] = _TPSTATEDELETEREQUEST
DESCRIPTOR.message_types_by_name['TpStateDeleteResponse'] = _TPSTATEDELETERESPONSE
DESCRIPTOR.message_types_by_name['TpReceiptAddDataRequest'] = _TPRECEIPTADDDATAREQUEST
DESCRIPTOR.message_types_by_name['TpReceiptAddDataResponse'] = _TPRECEIPTADDDATARESPONSE
DESCRIPTOR.message_types_by_name['TpEventAddRequest'] = _TPEVENTADDREQUEST
DESCRIPTOR.message_types_by_name['TpEventAddResponse'] = _TPEVENTADDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TpStateEntry = _reflection.GeneratedProtocolMessageType('TpStateEntry', (_message.Message,), dict(
  DESCRIPTOR = _TPSTATEENTRY,
  __module__ = 'dgt_sdk.protobuf.state_context_pb2'
  # @@protoc_insertion_point(class_scope:TpStateEntry)
  ))
_sym_db.RegisterMessage(TpStateEntry)

TpStateGetRequest = _reflection.GeneratedProtocolMessageType('TpStateGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _TPSTATEGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.state_context_pb2'
  # @@protoc_insertion_point(class_scope:TpStateGetRequest)
  ))
_sym_db.RegisterMessage(TpStateGetRequest)

TpStateGetResponse = _reflection.GeneratedProtocolMessageType('TpStateGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _TPSTATEGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.state_context_pb2'
  # @@protoc_insertion_point(class_scope:TpStateGetResponse)
  ))
_sym_db.RegisterMessage(TpStateGetResponse)

TpStateSetRequest = _reflection.GeneratedProtocolMessageType('TpStateSetRequest', (_message.Message,), dict(
  DESCRIPTOR = _TPSTATESETREQUEST,
  __module__ = 'dgt_sdk.protobuf.state_context_pb2'
  # @@protoc_insertion_point(class_scope:TpStateSetRequest)
  ))
_sym_db.RegisterMessage(TpStateSetRequest)

TpStateSetResponse = _reflection.GeneratedProtocolMessageType('TpStateSetResponse', (_message.Message,), dict(
  DESCRIPTOR = _TPSTATESETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.state_context_pb2'
  # @@protoc_insertion_point(class_scope:TpStateSetResponse)
  ))
_sym_db.RegisterMessage(TpStateSetResponse)

TpStateDeleteRequest = _reflection.GeneratedProtocolMessageType('TpStateDeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _TPSTATEDELETEREQUEST,
  __module__ = 'dgt_sdk.protobuf.state_context_pb2'
  # @@protoc_insertion_point(class_scope:TpStateDeleteRequest)
  ))
_sym_db.RegisterMessage(TpStateDeleteRequest)

TpStateDeleteResponse = _reflection.GeneratedProtocolMessageType('TpStateDeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _TPSTATEDELETERESPONSE,
  __module__ = 'dgt_sdk.protobuf.state_context_pb2'
  # @@protoc_insertion_point(class_scope:TpStateDeleteResponse)
  ))
_sym_db.RegisterMessage(TpStateDeleteResponse)

TpReceiptAddDataRequest = _reflection.GeneratedProtocolMessageType('TpReceiptAddDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _TPRECEIPTADDDATAREQUEST,
  __module__ = 'dgt_sdk.protobuf.state_context_pb2'
  # @@protoc_insertion_point(class_scope:TpReceiptAddDataRequest)
  ))
_sym_db.RegisterMessage(TpReceiptAddDataRequest)

TpReceiptAddDataResponse = _reflection.GeneratedProtocolMessageType('TpReceiptAddDataResponse', (_message.Message,), dict(
  DESCRIPTOR = _TPRECEIPTADDDATARESPONSE,
  __module__ = 'dgt_sdk.protobuf.state_context_pb2'
  # @@protoc_insertion_point(class_scope:TpReceiptAddDataResponse)
  ))
_sym_db.RegisterMessage(TpReceiptAddDataResponse)

TpEventAddRequest = _reflection.GeneratedProtocolMessageType('TpEventAddRequest', (_message.Message,), dict(
  DESCRIPTOR = _TPEVENTADDREQUEST,
  __module__ = 'dgt_sdk.protobuf.state_context_pb2'
  # @@protoc_insertion_point(class_scope:TpEventAddRequest)
  ))
_sym_db.RegisterMessage(TpEventAddRequest)

TpEventAddResponse = _reflection.GeneratedProtocolMessageType('TpEventAddResponse', (_message.Message,), dict(
  DESCRIPTOR = _TPEVENTADDRESPONSE,
  __module__ = 'dgt_sdk.protobuf.state_context_pb2'
  # @@protoc_insertion_point(class_scope:TpEventAddResponse)
  ))
_sym_db.RegisterMessage(TpEventAddResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/validator.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/validator.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\rvalidator_pb2'),
  serialized_pb=_b('\n dgt_sdk/protobuf/validator.proto\")\n\x0bMessageList\x12\x1a\n\x08messages\x18\x01 \x03(\x0b\x32\x08.Message\"\xb4\"\n\x07Message\x12*\n\x0cmessage_type\x18\x01 \x01(\x0e\x32\x14.Message.MessageType\x12\x16\n\x0e\x63orrelation_id\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\"\xd3!\n\x0bMessageType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x17\n\x13TP_REGISTER_REQUEST\x10\x01\x12\x18\n\x14TP_REGISTER_RESPONSE\x10\x02\x12\x19\n\x15TP_UNREGISTER_REQUEST\x10\x03\x12\x1a\n\x16TP_UNREGISTER_RESPONSE\x10\x04\x12\x16\n\x12TP_PROCESS_REQUEST\x10\x05\x12\x17\n\x13TP_PROCESS_RESPONSE\x10\x06\x12\x18\n\x14TP_STATE_GET_REQUEST\x10\x07\x12\x19\n\x15TP_STATE_GET_RESPONSE\x10\x08\x12\x18\n\x14TP_STATE_SET_REQUEST\x10\t\x12\x19\n\x15TP_STATE_SET_RESPONSE\x10\n\x12\x1b\n\x17TP_STATE_DELETE_REQUEST\x10\x0b\x12\x1c\n\x18TP_STATE_DELETE_RESPONSE\x10\x0c\x12\x1f\n\x1bTP_RECEIPT_ADD_DATA_REQUEST\x10\r\x12 \n\x1cTP_RECEIPT_ADD_DATA_RESPONSE\x10\x0e\x12\x18\n\x14TP_EVENT_ADD_REQUEST\x10\x0f\x12\x19\n\x15TP_EVENT_ADD_RESPONSE\x10\x10\x12\x1f\n\x1b\x43LIENT_BATCH_SUBMIT_REQUEST\x10\x64\x12 \n\x1c\x43LIENT_BATCH_SUBMIT_RESPONSE\x10\x65\x12\x1d\n\x19\x43LIENT_BLOCK_LIST_REQUEST\x10\x66\x12\x1e\n\x1a\x43LIENT_BLOCK_LIST_RESPONSE\x10g\x12\"\n\x1e\x43LIENT_BLOCK_GET_BY_ID_REQUEST\x10h\x12\x1d\n\x19\x43LIENT_BLOCK_GET_RESPONSE\x10i\x12\x1d\n\x19\x43LIENT_BATCH_LIST_REQUEST\x10j\x12\x1e\n\x1a\x43LIENT_BATCH_LIST_RESPONSE\x10k\x12\x1c\n\x18\x43LIENT_BATCH_GET_REQUEST\x10l\x12\x1d\n\x19\x43LIENT_BATCH_GET_RESPONSE\x10m\x12#\n\x1f\x43LIENT_TRANSACTION_LIST_REQUEST\x10n\x12$\n CLIENT_TRANSACTION_LIST_RESPONSE\x10o\x12\"\n\x1e\x43LIENT_TRANSACTION_GET_REQUEST\x10p\x12#\n\x1f\x43LIENT_TRANSACTION_GET_RESPONSE\x10q\x12 \n\x1c\x43LIENT_STATE_CURRENT_REQUEST\x10r\x12!\n\x1d\x43LIENT_STATE_CURRENT_RESPONSE\x10s\x12\x1d\n\x19\x43LIENT_STATE_LIST_REQUEST\x10t\x12\x1e\n\x1a\x43LIENT_STATE_LIST_RESPONSE\x10u\x12\x1c\n\x18\x43LIENT_STATE_GET_REQUEST\x10v\x12\x1d\n\x19\x43LIENT_STATE_GET_RESPONSE\x10w\x12\x1f\n\x1b\x43LIENT_BATCH_STATUS_REQUEST\x10x\x12 \n\x1c\x43LIENT_BATCH_STATUS_RESPONSE\x10y\x12\x1e\n\x1a\x43LIENT_RECEIPT_GET_REQUEST\x10z\x12\x1f\n\x1b\x43LIENT_RECEIPT_GET_RESPONSE\x10{\x12#\n\x1f\x43LIENT_BLOCK_GET_BY_NUM_REQUEST\x10|\x12\x1c\n\x18\x43LIENT_PEERS_GET_REQUEST\x10}\x12\x1d\n\x19\x43LIENT_PEERS_GET_RESPONSE\x10~\x12.\n*CLIENT_BLOCK_GET_BY_TRANSACTION_ID_REQUEST\x10\x7f\x12)\n$CLIENT_BLOCK_GET_BY_BATCH_ID_REQUEST\x10\x80\x01\x12\x1e\n\x19\x43LIENT_STATUS_GET_REQUEST\x10\x81\x01\x12\x1f\n\x1a\x43LIENT_STATUS_GET_RESPONSE\x10\x82\x01\x12\x1d\n\x18\x43LIENT_HEADS_GET_REQUEST\x10\x83\x01\x12\x1e\n\x19\x43LIENT_HEADS_GET_RESPONSE\x10\x84\x01\x12 \n\x1b\x43LIENT_TOPOLOGY_GET_REQUEST\x10\x85\x01\x12!\n\x1c\x43LIENT_TOPOLOGY_GET_RESPONSE\x10\x86\x01\x12!\n\x1c\x43LIENT_PEERS_CONTROL_REQUEST\x10\x87\x01\x12\"\n\x1d\x43LIENT_PEERS_CONTROL_RESPONSE\x10\x88\x01\x12\x1d\n\x18\x43LIENT_GRAPH_GET_REQUEST\x10\x89\x01\x12\x1e\n\x19\x43LIENT_GRAPH_GET_RESPONSE\x10\x8a\x01\x12$\n\x1f\x43LIENT_EVENTS_SUBSCRIBE_REQUEST\x10\xf4\x03\x12%\n CLIENT_EVENTS_SUBSCRIBE_RESPONSE\x10\xf5\x03\x12&\n!CLIENT_EVENTS_UNSUBSCRIBE_REQUEST\x10\xf6\x03\x12\'\n\"CLIENT_EVENTS_UNSUBSCRIBE_RESPONSE\x10\xf7\x03\x12\x12\n\rCLIENT_EVENTS\x10\xf8\x03\x12\x1e\n\x19\x43LIENT_EVENTS_GET_REQUEST\x10\xf9\x03\x12\x1f\n\x1a\x43LIENT_EVENTS_GET_RESPONSE\x10\xfa\x03\x12\x13\n\x0eGOSSIP_MESSAGE\x10\xc8\x01\x12\x14\n\x0fGOSSIP_REGISTER\x10\xc9\x01\x12\x16\n\x11GOSSIP_UNREGISTER\x10\xca\x01\x12\x19\n\x14GOSSIP_BLOCK_REQUEST\x10\xcd\x01\x12\x1a\n\x15GOSSIP_BLOCK_RESPONSE\x10\xce\x01\x12%\n GOSSIP_BATCH_BY_BATCH_ID_REQUEST\x10\xcf\x01\x12+\n&GOSSIP_BATCH_BY_TRANSACTION_ID_REQUEST\x10\xd0\x01\x12\x1a\n\x15GOSSIP_BATCH_RESPONSE\x10\xd1\x01\x12\x1d\n\x18GOSSIP_GET_PEERS_REQUEST\x10\xd2\x01\x12\x1e\n\x19GOSSIP_GET_PEERS_RESPONSE\x10\xd3\x01\x12\x1d\n\x18GOSSIP_CONSENSUS_MESSAGE\x10\xd4\x01\x12\x10\n\x0bNETWORK_ACK\x10\xac\x02\x12\x14\n\x0fNETWORK_CONNECT\x10\xad\x02\x12\x17\n\x12NETWORK_DISCONNECT\x10\xae\x02\x12&\n!AUTHORIZATION_CONNECTION_RESPONSE\x10\xd8\x04\x12\x1c\n\x17\x41UTHORIZATION_VIOLATION\x10\xd9\x04\x12 \n\x1b\x41UTHORIZATION_TRUST_REQUEST\x10\xda\x04\x12!\n\x1c\x41UTHORIZATION_TRUST_RESPONSE\x10\xdb\x04\x12$\n\x1f\x41UTHORIZATION_CHALLENGE_REQUEST\x10\xdc\x04\x12%\n AUTHORIZATION_CHALLENGE_RESPONSE\x10\xdd\x04\x12#\n\x1e\x41UTHORIZATION_CHALLENGE_SUBMIT\x10\xde\x04\x12#\n\x1e\x41UTHORIZATION_CHALLENGE_RESULT\x10\xdf\x04\x12\x11\n\x0cPING_REQUEST\x10\xbc\x05\x12\x12\n\rPING_RESPONSE\x10\xbd\x05\x12\x1f\n\x1a\x43ONSENSUS_REGISTER_REQUEST\x10\xa0\x06\x12 \n\x1b\x43ONSENSUS_REGISTER_RESPONSE\x10\xa1\x06\x12\x1e\n\x19\x43ONSENSUS_SEND_TO_REQUEST\x10\xa2\x06\x12\x1f\n\x1a\x43ONSENSUS_SEND_TO_RESPONSE\x10\xa3\x06\x12 \n\x1b\x43ONSENSUS_BROADCAST_REQUEST\x10\xa4\x06\x12!\n\x1c\x43ONSENSUS_BROADCAST_RESPONSE\x10\xa5\x06\x12\'\n\"CONSENSUS_INITIALIZE_BLOCK_REQUEST\x10\xa6\x06\x12(\n#CONSENSUS_INITIALIZE_BLOCK_RESPONSE\x10\xa7\x06\x12%\n CONSENSUS_FINALIZE_BLOCK_REQUEST\x10\xa8\x06\x12&\n!CONSENSUS_FINALIZE_BLOCK_RESPONSE\x10\xa9\x06\x12&\n!CONSENSUS_SUMMARIZE_BLOCK_REQUEST\x10\xbc\x06\x12\'\n\"CONSENSUS_SUMMARIZE_BLOCK_RESPONSE\x10\xbd\x06\x12#\n\x1e\x43ONSENSUS_CANCEL_BLOCK_REQUEST\x10\xaa\x06\x12$\n\x1f\x43ONSENSUS_CANCEL_BLOCK_RESPONSE\x10\xab\x06\x12#\n\x1e\x43ONSENSUS_CHECK_BLOCKS_REQUEST\x10\xac\x06\x12$\n\x1f\x43ONSENSUS_CHECK_BLOCKS_RESPONSE\x10\xad\x06\x12#\n\x1e\x43ONSENSUS_COMMIT_BLOCK_REQUEST\x10\xae\x06\x12$\n\x1f\x43ONSENSUS_COMMIT_BLOCK_RESPONSE\x10\xaf\x06\x12#\n\x1e\x43ONSENSUS_IGNORE_BLOCK_REQUEST\x10\xb0\x06\x12$\n\x1f\x43ONSENSUS_IGNORE_BLOCK_RESPONSE\x10\xb1\x06\x12!\n\x1c\x43ONSENSUS_FAIL_BLOCK_REQUEST\x10\xb2\x06\x12\"\n\x1d\x43ONSENSUS_FAIL_BLOCK_RESPONSE\x10\xb3\x06\x12#\n\x1e\x43ONSENSUS_SETTINGS_GET_REQUEST\x10\xb4\x06\x12$\n\x1f\x43ONSENSUS_SETTINGS_GET_RESPONSE\x10\xb5\x06\x12 \n\x1b\x43ONSENSUS_STATE_GET_REQUEST\x10\xb6\x06\x12!\n\x1c\x43ONSENSUS_STATE_GET_RESPONSE\x10\xb7\x06\x12!\n\x1c\x43ONSENSUS_BLOCKS_GET_REQUEST\x10\xb8\x06\x12\"\n\x1d\x43ONSENSUS_BLOCKS_GET_RESPONSE\x10\xb9\x06\x12%\n CONSENSUS_CHAIN_HEAD_GET_REQUEST\x10\xba\x06\x12&\n!CONSENSUS_CHAIN_HEAD_GET_RESPONSE\x10\xbb\x06\x12(\n#CONSENSUS_BROADCAST_ARBITER_REQUEST\x10\xbe\x06\x12)\n$CONSENSUS_BROADCAST_ARBITER_RESPONSE\x10\xbf\x06\x12(\n#CONSENSUS_BROADCAST_CLUSTER_REQUEST\x10\xc0\x06\x12)\n$CONSENSUS_BROADCAST_CLUSTER_RESPONSE\x10\xc1\x06\x12$\n\x1f\x43ONSENSUS_NOTIFY_PEER_CONNECTED\x10\x84\x07\x12\'\n\"CONSENSUS_NOTIFY_PEER_DISCONNECTED\x10\x85\x07\x12\"\n\x1d\x43ONSENSUS_NOTIFY_PEER_MESSAGE\x10\x86\x07\x12\x1f\n\x1a\x43ONSENSUS_NOTIFY_BLOCK_NEW\x10\x87\x07\x12!\n\x1c\x43ONSENSUS_NOTIFY_BLOCK_VALID\x10\x88\x07\x12#\n\x1e\x43ONSENSUS_NOTIFY_BLOCK_INVALID\x10\x89\x07\x12\"\n\x1d\x43ONSENSUS_NOTIFY_BLOCK_COMMIT\x10\x8a\x07\x12\x19\n\x14\x43ONSENSUS_NOTIFY_ACK\x10\xe7\x07\x42(\n\x15sawtooth.sdk.protobufP\x01Z\rvalidator_pb2b\x06proto3')
)



_MESSAGE_MESSAGETYPE = _descriptor.EnumDescriptor(
  name='MessageType',
  full_name='Message.MessageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TP_REGISTER_REQUEST', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TP_REGISTER_RESPONSE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TP_UNREGISTER_REQUEST', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TP_UNREGISTER_RESPONSE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TP_PROCESS_REQUEST', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TP_PROCESS_RESPONSE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TP_STATE_GET_REQUEST', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TP_STATE_GET_RESPONSE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TP_STATE_SET_REQUEST', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TP_STATE_SET_RESPONSE', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TP_STATE_DELETE_REQUEST', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TP_STATE_DELETE_RESPONSE', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TP_RECEIPT_ADD_DATA_REQUEST', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TP_RECEIPT_ADD_DATA_RESPONSE', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TP_EVENT_ADD_REQUEST', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TP_EVENT_ADD_RESPONSE', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_BATCH_SUBMIT_REQUEST', index=17, number=100,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_BATCH_SUBMIT_RESPONSE', index=18, number=101,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_BLOCK_LIST_REQUEST', index=19, number=102,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_BLOCK_LIST_RESPONSE', index=20, number=103,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_BLOCK_GET_BY_ID_REQUEST', index=21, number=104,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_BLOCK_GET_RESPONSE', index=22, number=105,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_BATCH_LIST_REQUEST', index=23, number=106,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_BATCH_LIST_RESPONSE', index=24, number=107,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_BATCH_GET_REQUEST', index=25, number=108,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_BATCH_GET_RESPONSE', index=26, number=109,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_TRANSACTION_LIST_REQUEST', index=27, number=110,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_TRANSACTION_LIST_RESPONSE', index=28, number=111,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_TRANSACTION_GET_REQUEST', index=29, number=112,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_TRANSACTION_GET_RESPONSE', index=30, number=113,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_STATE_CURRENT_REQUEST', index=31, number=114,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_STATE_CURRENT_RESPONSE', index=32, number=115,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_STATE_LIST_REQUEST', index=33, number=116,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_STATE_LIST_RESPONSE', index=34, number=117,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_STATE_GET_REQUEST', index=35, number=118,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_STATE_GET_RESPONSE', index=36, number=119,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_BATCH_STATUS_REQUEST', index=37, number=120,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_BATCH_STATUS_RESPONSE', index=38, number=121,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_RECEIPT_GET_REQUEST', index=39, number=122,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_RECEIPT_GET_RESPONSE', index=40, number=123,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_BLOCK_GET_BY_NUM_REQUEST', index=41, number=124,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_PEERS_GET_REQUEST', index=42, number=125,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_PEERS_GET_RESPONSE', index=43, number=126,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_BLOCK_GET_BY_TRANSACTION_ID_REQUEST', index=44, number=127,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_BLOCK_GET_BY_BATCH_ID_REQUEST', index=45, number=128,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_STATUS_GET_REQUEST', index=46, number=129,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_STATUS_GET_RESPONSE', index=47, number=130,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_HEADS_GET_REQUEST', index=48, number=131,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_HEADS_GET_RESPONSE', index=49, number=132,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_TOPOLOGY_GET_REQUEST', index=50, number=133,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_TOPOLOGY_GET_RESPONSE', index=51, number=134,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_PEERS_CONTROL_REQUEST', index=52, number=135,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_PEERS_CONTROL_RESPONSE', index=53, number=136,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_GRAPH_GET_REQUEST', index=54, number=137,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_GRAPH_GET_RESPONSE', index=55, number=138,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_EVENTS_SUBSCRIBE_REQUEST', index=56, number=500,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_EVENTS_SUBSCRIBE_RESPONSE', index=57, number=501,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_EVENTS_UNSUBSCRIBE_REQUEST', index=58, number=502,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_EVENTS_UNSUBSCRIBE_RESPONSE', index=59, number=503,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_EVENTS', index=60, number=504,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_EVENTS_GET_REQUEST', index=61, number=505,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_EVENTS_GET_RESPONSE', index=62, number=506,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOSSIP_MESSAGE', index=63, number=200,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOSSIP_REGISTER', index=64, number=201,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOSSIP_UNREGISTER', index=65, number=202,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOSSIP_BLOCK_REQUEST', index=66, number=205,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOSSIP_BLOCK_RESPONSE', index=67, number=206,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOSSIP_BATCH_BY_BATCH_ID_REQUEST', index=68, number=207,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOSSIP_BATCH_BY_TRANSACTION_ID_REQUEST', index=69, number=208,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOSSIP_BATCH_RESPONSE', index=70, number=209,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOSSIP_GET_PEERS_REQUEST', index=71, number=210,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOSSIP_GET_PEERS_RESPONSE', index=72, number=211,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOSSIP_CONSENSUS_MESSAGE', index=73, number=212,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_ACK', index=74, number=300,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_CONNECT', index=75, number=301,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_DISCONNECT', index=76, number=302,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_CONNECTION_RESPONSE', index=77, number=600,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_VIOLATION', index=78, number=601,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_TRUST_REQUEST', index=79, number=602,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_TRUST_RESPONSE', index=80, number=603,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_CHALLENGE_REQUEST', index=81, number=604,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_CHALLENGE_RESPONSE', index=82, number=605,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_CHALLENGE_SUBMIT', index=83, number=606,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_CHALLENGE_RESULT', index=84, number=607,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PING_REQUEST', index=85, number=700,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PING_RESPONSE', index=86, number=701,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_REGISTER_REQUEST', index=87, number=800,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_REGISTER_RESPONSE', index=88, number=801,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_SEND_TO_REQUEST', index=89, number=802,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_SEND_TO_RESPONSE', index=90, number=803,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_BROADCAST_REQUEST', index=91, number=804,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_BROADCAST_RESPONSE', index=92, number=805,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_INITIALIZE_BLOCK_REQUEST', index=93, number=806,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_INITIALIZE_BLOCK_RESPONSE', index=94, number=807,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_FINALIZE_BLOCK_REQUEST', index=95, number=808,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_FINALIZE_BLOCK_RESPONSE', index=96, number=809,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_SUMMARIZE_BLOCK_REQUEST', index=97, number=828,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_SUMMARIZE_BLOCK_RESPONSE', index=98, number=829,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_CANCEL_BLOCK_REQUEST', index=99, number=810,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_CANCEL_BLOCK_RESPONSE', index=100, number=811,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_CHECK_BLOCKS_REQUEST', index=101, number=812,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_CHECK_BLOCKS_RESPONSE', index=102, number=813,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_COMMIT_BLOCK_REQUEST', index=103, number=814,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_COMMIT_BLOCK_RESPONSE', index=104, number=815,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_IGNORE_BLOCK_REQUEST', index=105, number=816,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_IGNORE_BLOCK_RESPONSE', index=106, number=817,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_FAIL_BLOCK_REQUEST', index=107, number=818,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_FAIL_BLOCK_RESPONSE', index=108, number=819,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_SETTINGS_GET_REQUEST', index=109, number=820,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_SETTINGS_GET_RESPONSE', index=110, number=821,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_STATE_GET_REQUEST', index=111, number=822,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_STATE_GET_RESPONSE', index=112, number=823,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_BLOCKS_GET_REQUEST', index=113, number=824,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_BLOCKS_GET_RESPONSE', index=114, number=825,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_CHAIN_HEAD_GET_REQUEST', index=115, number=826,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_CHAIN_HEAD_GET_RESPONSE', index=116, number=827,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_BROADCAST_ARBITER_REQUEST', index=117, number=830,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_BROADCAST_ARBITER_RESPONSE', index=118, number=831,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_BROADCAST_CLUSTER_REQUEST', index=119, number=832,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_BROADCAST_CLUSTER_RESPONSE', index=120, number=833,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_NOTIFY_PEER_CONNECTED', index=121, number=900,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_NOTIFY_PEER_DISCONNECTED', index=122, number=901,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_NOTIFY_PEER_MESSAGE', index=123, number=902,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_NOTIFY_BLOCK_NEW', index=124, number=903,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_NOTIFY_BLOCK_VALID', index=125, number=904,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_NOTIFY_BLOCK_INVALID', index=126, number=905,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_NOTIFY_BLOCK_COMMIT', index=127, number=906,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSENSUS_NOTIFY_ACK', index=128, number=999,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=177,
  serialized_end=4484,
)
_sym_db.RegisterEnumDescriptor(_MESSAGE_MESSAGETYPE)


_MESSAGELIST = _descriptor.Descriptor(
  name='MessageList',
  full_name='MessageList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='MessageList.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=77,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_type', full_name='Message.message_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='correlation_id', full_name='Message.correlation_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='Message.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MESSAGE_MESSAGETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=4484,
)

_MESSAGELIST.fields_by_name['messages'].message_type = _MESSAGE
_MESSAGE.fields_by_name['message_type'].enum_type = _MESSAGE_MESSAGETYPE
_MESSAGE_MESSAGETYPE.containing_type = _MESSAGE
DESCRIPTOR.message_types_by_name['MessageList'] = _MESSAGELIST
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MessageList = _reflection.GeneratedProtocolMessageType('MessageList', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGELIST,
  __module__ = 'dgt_sdk.protobuf.validator_pb2'
  # @@protoc_insertion_point(class_scope:MessageList)
  ))
_sym_db.RegisterMessage(MessageList)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGE,
  __module__ = 'dgt_sdk.protobuf.validator_pb2'
  # @@protoc_insertion_point(class_scope:Message)
  ))
_sym_db.RegisterMessage(Message)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Copyright 2019 DGT NETWORK INC © Stanislav Parsov © Stanislav Parsov
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ------------------------------------------------------------------------------
from dgt_sdk.protobuf.validator_pb2 import Message
from dgt_sdk.protobuf import state_context_pb2
from dgt_sdk.protobuf import events_pb2
from dgt_sdk.processor.exceptions import InternalError
from dgt_sdk.processor.exceptions import AuthorizationException


class Context:
    """
    Context provides an interface for getting, setting, and deleting
    validator state. All validator interactions by a handler should be
    through a Context instance.

    Attributes:
        _stream (sawtooth.client.stream.Stream): client grpc communication
        _context_id (str): the context_id passed in from the validator

    """

    def __init__(self, stream, context_id):
        self._stream = stream
        self._context_id = context_id

    def get_state(self, addresses, timeout=None):
        """
        get_state queries the validator state for data at each of the
        addresses in the given list. The addresses that have been set
        are returned in a list.

        Args:
            addresses (list): the addresses to fetch
            timeout: optional timeout, in seconds
        Returns:
            results (list): a list of Entries (address, data), for the
            addresses that have a value

        Raises:
            AuthorizationException
        """
        request = state_context_pb2.TpStateGetRequest(
            context_id=self._context_id,
            addresses=addresses)
        response_string = self._stream.send(
            Message.TP_STATE_GET_REQUEST,
            request.SerializeToString()).result(timeout).content
        response = state_context_pb2.TpStateGetResponse()
        response.ParseFromString(response_string)
        if response.status == state_context_pb2.TpStateGetResponse.AUTHORIZATION_ERROR:
            raise AuthorizationException('Tried to get unauthorized address: {}'.format(addresses))

        entries = response.entries if response is not None else []
        results = [e for e in entries if len(e.data) != 0]
        return results

    def set_state(self, entries, timeout=None):
        """
        set_state requests that each address in the provided dictionary be
        set in validator state to its corresponding value. A list is
        returned containing the successfully set addresses.

        Args:
            entries (dict): dictionary where addresses are the keys and data is
                the value.
            timeout: optional timeout, in seconds

        Returns:
            addresses (list): a list of addresses that were set

        Raises:
            AuthorizationException
        """
        state_entries = [
            state_context_pb2.TpStateEntry(address=e, data=entries[e])
            for e in entries
        ]
        request = state_context_pb2.TpStateSetRequest(
            entries=state_entries,
            context_id=self._context_id).SerializeToString()
        response = state_context_pb2.TpStateSetResponse()
        response.ParseFromString(
            self._stream.send(Message.TP_STATE_SET_REQUEST,
                              request).result(timeout).content)
        if response.status == \
                state_context_pb2.TpStateSetResponse.AUTHORIZATION_ERROR:
            addresses = [e.address for e in state_entries]
            raise AuthorizationException(
                'Tried to set unauthorized address: {}'.format(addresses))
        return response.addresses

    def delete_state(self, addresses, timeout=None):
        """
        delete_state requests that each of the provided addresses be unset
        in validator state. A list of successfully deleted addresses
        is returned.

        Args:
            addresses (list): list of addresses to delete
            timeout: optional timeout, in seconds

        Returns:
            addresses (list): a list of addresses that were deleted

        Raises:
            AuthorizationException
        """
        request = state_context_pb2.TpStateDeleteRequest(
            context_id=self._context_id,
            addresses=addresses).SerializeToString()
        response = state_context_pb2.TpStateDeleteResponse()
        response.ParseFromString(
            self._stream.send(Message.TP_STATE_DELETE_REQUEST,
                              request).result(timeout).content)
        if response.status == \
                state_context_pb2.TpStateDeleteResponse.AUTHORIZATION_ERROR:
            raise AuthorizationException(
                'Tried to delete unauthorized address: {}'.format(addresses))
        return response.addresses

    def add_receipt_data(self, data, timeout=None):
        """Add a blob to the execution result for this transaction.

        Args:
            data (bytes): The data to add.
        """
        request = state_context_pb2.TpReceiptAddDataRequest(
            context_id=self._context_id,
            data=data).SerializeToString()
        response = state_context_pb2.TpReceiptAddDataResponse()
        response.ParseFromString(
            self._stream.send(
                Message.TP_RECEIPT_ADD_DATA_REQUEST,
                request).result(timeout).content)
        if response.status == state_context_pb2.TpReceiptAddDataResponse.ERROR:
            raise InternalError(
                "Failed to add receipt data: {}".format((data)))

    def add_event(self, event_type, attributes=None, data=None, timeout=None):
        """Add a new event to the execution result for this transaction.

        Args:
            event_type (str): This is used to subscribe to events. It should be
                globally unique and describe what, in general, has occured.
            attributes (list of (str, str) tuples): Additional information
                about the event that is transparent to the validator.
                Attributes can be used by subscribers to filter the type of
                events they receive.
            data (bytes): Additional information about the event that is opaque
                to the validator.
        """
        if attributes is None:
            attributes = []

        event = events_pb2.Event(
            event_type=event_type,
            attributes=[
                events_pb2.Event.Attribute(key=key, value=value)
                for key, value in attributes
            ],
            data=data,
        )
        request = state_context_pb2.TpEventAddRequest(
            context_id=self._context_id, event=event).SerializeToString()
        response = state_context_pb2.TpEventAddResponse()
        response.ParseFromString(
            self._stream.send(
                Message.TP_EVENT_ADD_REQUEST,
                request).result(timeout).content)
        if response.status == state_context_pb2.TpEventAddResponse.ERROR:
            raise InternalError(
                "Failed to add event: ({}, {}, {})".format(
                    event_type, attributes, data))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/client_topology.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/client_topology.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\017client_topology'),
  serialized_pb=_b('\n&dgt_sdk/protobuf/client_topology.proto\"\x1a\n\x18\x43lientTopologyGetRequest\"\x8f\x01\n\x19\x43lientTopologyGetResponse\x12\x31\n\x06status\x18\x01 \x01(\x0e\x32!.ClientTopologyGetResponse.Status\x12\x10\n\x08topology\x18\x02 \x01(\x0c\"-\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x42*\n\x15sawtooth.sdk.protobufP\x01Z\x0f\x63lient_topologyb\x06proto3')
)



_CLIENTTOPOLOGYGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientTopologyGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=169,
  serialized_end=214,
)
_sym_db.RegisterEnumDescriptor(_CLIENTTOPOLOGYGETRESPONSE_STATUS)


_CLIENTTOPOLOGYGETREQUEST = _descriptor.Descriptor(
  name='ClientTopologyGetRequest',
  full_name='ClientTopologyGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=68,
)


_CLIENTTOPOLOGYGETRESPONSE = _descriptor.Descriptor(
  name='ClientTopologyGetResponse',
  full_name='ClientTopologyGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientTopologyGetResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='topology', full_name='ClientTopologyGetResponse.topology', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTTOPOLOGYGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=214,
)

_CLIENTTOPOLOGYGETRESPONSE.fields_by_name['status'].enum_type = _CLIENTTOPOLOGYGETRESPONSE_STATUS
_CLIENTTOPOLOGYGETRESPONSE_STATUS.containing_type = _CLIENTTOPOLOGYGETRESPONSE
DESCRIPTOR.message_types_by_name['ClientTopologyGetRequest'] = _CLIENTTOPOLOGYGETREQUEST
DESCRIPTOR.message_types_by_name['ClientTopologyGetResponse'] = _CLIENTTOPOLOGYGETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientTopologyGetRequest = _reflection.GeneratedProtocolMessageType('ClientTopologyGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTTOPOLOGYGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_topology_pb2'
  # @@protoc_insertion_point(class_scope:ClientTopologyGetRequest)
  ))
_sym_db.RegisterMessage(ClientTopologyGetRequest)

ClientTopologyGetResponse = _reflection.GeneratedProtocolMessageType('ClientTopologyGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTTOPOLOGYGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_topology_pb2'
  # @@protoc_insertion_point(class_scope:ClientTopologyGetResponse)
  ))
_sym_db.RegisterMessage(ClientTopologyGetResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from setuptools import setup
from setuptools import find_packages
from distutils.util import convert_path
main_ns={}
ver_path=convert_path("client/VER.py")

with open(ver_path) as ver_file:
    exec(ver_file.read(), main_ns)

setup( name="BGT Client",
        version=main_ns['__version__'],
        description = "This package provides a client for the BGT transaction family",
        author = "Misha Khvatov",
        author_email = "misha.khvatov@gmail.com",
        url="https://github.com/Mishark-dev/DGT-Client",
        entry_points={'console_scripts' :
            [
                "bgtc = client.main:main"

                ]
            },
        exclude=["config"],
        packages=find_packages(),
        install_requires=['requests','ipaddress','cbor',
                          'protobuf==3.20','cryptography','configparser','secp256k1']

        )



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/bgx_validator_registry.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/bgx_validator_registry.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\030sawtooth.config.protobufP\001'),
  serialized_pb=_b('\n-dgt_sdk/protobuf/bgx_validator_registry.proto\"w\n\x10\x42gxValidatorInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04node\x18\x03 \x01(\t\x12#\n\x0bsignup_info\x18\x04 \x01(\x0b\x32\x0e.BgxSignUpInfo\x12\x16\n\x0etransaction_id\x18\x05 \x01(\t\"N\n\rBgxSignUpInfo\x12\x17\n\x0fpbft_public_key\x18\x01 \x01(\t\x12\x15\n\ranti_sybil_id\x18\x02 \x01(\t\x12\r\n\x05nonce\x18\x03 \x01(\t\"_\n\x0f\x42gxValidatorMap\x12\'\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x16.BgxValidatorMap.Entry\x1a#\n\x05\x45ntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"x\n\x1b\x42gxValidatorRegistryPayload\x12\x0c\n\x04verb\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04node\x18\x04 \x01(\t\x12#\n\x0bsignup_info\x18\x05 \x01(\x0b\x32\x0e.BgxSignUpInfoB\x1c\n\x18sawtooth.config.protobufP\x01\x62\x06proto3')
)




_BGXVALIDATORINFO = _descriptor.Descriptor(
  name='BgxValidatorInfo',
  full_name='BgxValidatorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='BgxValidatorInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='BgxValidatorInfo.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node', full_name='BgxValidatorInfo.node', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signup_info', full_name='BgxValidatorInfo.signup_info', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='BgxValidatorInfo.transaction_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=168,
)


_BGXSIGNUPINFO = _descriptor.Descriptor(
  name='BgxSignUpInfo',
  full_name='BgxSignUpInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pbft_public_key', full_name='BgxSignUpInfo.pbft_public_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='anti_sybil_id', full_name='BgxSignUpInfo.anti_sybil_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='BgxSignUpInfo.nonce', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=248,
)


_BGXVALIDATORMAP_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='BgxValidatorMap.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='BgxValidatorMap.Entry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='BgxValidatorMap.Entry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=345,
)

_BGXVALIDATORMAP = _descriptor.Descriptor(
  name='BgxValidatorMap',
  full_name='BgxValidatorMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='BgxValidatorMap.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BGXVALIDATORMAP_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=345,
)


_BGXVALIDATORREGISTRYPAYLOAD = _descriptor.Descriptor(
  name='BgxValidatorRegistryPayload',
  full_name='BgxValidatorRegistryPayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='verb', full_name='BgxValidatorRegistryPayload.verb', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='BgxValidatorRegistryPayload.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='BgxValidatorRegistryPayload.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node', full_name='BgxValidatorRegistryPayload.node', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signup_info', full_name='BgxValidatorRegistryPayload.signup_info', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=467,
)

_BGXVALIDATORINFO.fields_by_name['signup_info'].message_type = _BGXSIGNUPINFO
_BGXVALIDATORMAP_ENTRY.containing_type = _BGXVALIDATORMAP
_BGXVALIDATORMAP.fields_by_name['entries'].message_type = _BGXVALIDATORMAP_ENTRY
_BGXVALIDATORREGISTRYPAYLOAD.fields_by_name['signup_info'].message_type = _BGXSIGNUPINFO
DESCRIPTOR.message_types_by_name['BgxValidatorInfo'] = _BGXVALIDATORINFO
DESCRIPTOR.message_types_by_name['BgxSignUpInfo'] = _BGXSIGNUPINFO
DESCRIPTOR.message_types_by_name['BgxValidatorMap'] = _BGXVALIDATORMAP
DESCRIPTOR.message_types_by_name['BgxValidatorRegistryPayload'] = _BGXVALIDATORREGISTRYPAYLOAD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BgxValidatorInfo = _reflection.GeneratedProtocolMessageType('BgxValidatorInfo', (_message.Message,), dict(
  DESCRIPTOR = _BGXVALIDATORINFO,
  __module__ = 'dgt_sdk.protobuf.bgx_validator_registry_pb2'
  # @@protoc_insertion_point(class_scope:BgxValidatorInfo)
  ))
_sym_db.RegisterMessage(BgxValidatorInfo)

BgxSignUpInfo = _reflection.GeneratedProtocolMessageType('BgxSignUpInfo', (_message.Message,), dict(
  DESCRIPTOR = _BGXSIGNUPINFO,
  __module__ = 'dgt_sdk.protobuf.bgx_validator_registry_pb2'
  # @@protoc_insertion_point(class_scope:BgxSignUpInfo)
  ))
_sym_db.RegisterMessage(BgxSignUpInfo)

BgxValidatorMap = _reflection.GeneratedProtocolMessageType('BgxValidatorMap', (_message.Message,), dict(

  Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
    DESCRIPTOR = _BGXVALIDATORMAP_ENTRY,
    __module__ = 'dgt_sdk.protobuf.bgx_validator_registry_pb2'
    # @@protoc_insertion_point(class_scope:BgxValidatorMap.Entry)
    ))
  ,
  DESCRIPTOR = _BGXVALIDATORMAP,
  __module__ = 'dgt_sdk.protobuf.bgx_validator_registry_pb2'
  # @@protoc_insertion_point(class_scope:BgxValidatorMap)
  ))
_sym_db.RegisterMessage(BgxValidatorMap)
_sym_db.RegisterMessage(BgxValidatorMap.Entry)

BgxValidatorRegistryPayload = _reflection.GeneratedProtocolMessageType('BgxValidatorRegistryPayload', (_message.Message,), dict(
  DESCRIPTOR = _BGXVALIDATORREGISTRYPAYLOAD,
  __module__ = 'dgt_sdk.protobuf.bgx_validator_registry_pb2'
  # @@protoc_insertion_point(class_scope:BgxValidatorRegistryPayload)
  ))
_sym_db.RegisterMessage(BgxValidatorRegistryPayload)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
